@@ -1,6 +1,6 @@
 /*
-    GNOME Commander - A GNOME based file manager 
-    Copyright (C) 2001-2003 Marcus Bjurman
+    GNOME Commander - A GNOME based file manager
+    Copyright (C) 2001-2006 Marcus Bjurman
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -15,21 +15,18 @@
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*/ 
+*/
 #ifndef __GNOME_CMD_MKDIR_DIALOG_H__
 #define __GNOME_CMD_MKDIR_DIALOG_H__
 
-#include "gnome-cmd-dir-types.h"
-#include "gnome-cmd-string-dialog.h"
-
-BEGIN_GNOME_DECLS
+#include "gnome-cmd-dir.h"
 
 #define GNOME_CMD_MKDIR_DIALOG(obj) \
-	GTK_CHECK_CAST (obj, gnome_cmd_mkdir_dialog_get_type (), GnomeCmdMkdirDialog)
+    GTK_CHECK_CAST (obj, gnome_cmd_mkdir_dialog_get_type (), GnomeCmdMkdirDialog)
 #define GNOME_CMD_MKDIR_DIALOG_CLASS(klass) \
-	GTK_CHECK_CLASS_CAST (klass, gnome_cmd_mkdir_dialog_get_type (), GnomeCmdMkdirDialogClass)
+    GTK_CHECK_CLASS_CAST (klass, gnome_cmd_mkdir_dialog_get_type (), GnomeCmdMkdirDialogClass)
 #define GNOME_CMD_IS_MKDIR_DIALOG(obj) \
-	GTK_CHECK_TYPE (obj, gnome_cmd_mkdir_dialog_get_type ())
+    GTK_CHECK_TYPE (obj, gnome_cmd_mkdir_dialog_get_type ())
 
 
 typedef struct _GnomeCmdMkdirDialog GnomeCmdMkdirDialog;
@@ -40,14 +37,14 @@ typedef struct _GnomeCmdMkdirDialogClass GnomeCmdMkdirDialogClass;
 
 struct _GnomeCmdMkdirDialog
 {
-	GnomeCmdStringDialog parent;
-	GnomeCmdMkdirDialogPrivate *priv;
+    GnomeCmdStringDialog parent;
+    GnomeCmdMkdirDialogPrivate *priv;
 };
 
 
 struct _GnomeCmdMkdirDialogClass
 {
-	GnomeCmdStringDialogClass parent_class;
+    GnomeCmdStringDialogClass parent_class;
 };
 
 
