@@ -1,6 +1,6 @@
 /*
-    GNOME Commander - A GNOME based file manager 
-    Copyright (C) 2001-2004 Marcus Bjurman
+    GNOME Commander - A GNOME based file manager
+    Copyright (C) 2001-2006 Marcus Bjurman
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,10 +22,10 @@
 
 typedef struct
 {
-	GList *ents;
-	GList *pos;
-	gint max;
-	gboolean lock;
+    GList *ents;
+    GList *pos;
+    gint max;
+    gboolean lock;
 } History;
 
 
@@ -37,7 +37,9 @@ void     history_add (History *history, const gchar *text);
 gboolean history_can_back (History *history);
 gboolean history_can_forward (History *history);
 
+const gchar   *history_first (History *history);
 const gchar   *history_back (History *history);
 const gchar   *history_forward (History *history);
+const gchar   *history_last (History *history);
 
 #endif //__HISTORY_H__
